@@ -86,6 +86,11 @@ c         to lower case letters.
       call c2lowerCase(temp, Job)
 
       call rndsw(jold, 1)    ! specify random number generator 1.
+
+c           set Target and do related xsec business; moved before
+c           cintModels (for qgsjet dummy ptcl generation in cQGSini)
+      call cixsec
+
 c       cintModels probably reads disk file(s) internally, 
 c       we may better to avoid simultaneous access to that disk 
 c       by different ranks; reading  starts from rank0, rank1...
@@ -123,8 +128,6 @@ c          manipulate data
 #endif
 c         init for geomag
       call crdGeomag(GeomagFile, YearOfGeomag)
-c           set Target and do related xsec business
-      call cixsec
 c        init for LPM effect energy sampling.
       s1 = (TargetAtomicN**(1./3.d0)/183.d0)**2
       call csetLPMCnst(s1, log(s1), 1.d-4, X0)
@@ -186,8 +189,8 @@ c         user hook
 
 c
 
-      integer i, now(2)
-      real*8 u
+      integer i
+       real*8 dstep 
 c  
 c
 c
@@ -199,33 +202,32 @@ c
          SkipPtclGen = 0
       endif
       
-c         set maximum moveable length (not sufficient but 
-c         necessary ) as 1/StepControl of the depth step.
-c         further conditions are put during tracking
-c         by cmaxMovLen.
 c
-      do i = 2, NoOfSites
-         maxstep(i) =( ObsSites(i).pos.depth -
-     *         ObsSites(i-1).pos.depth )/StepControl
+c    d = min( dZ/2, geneal min) for e+/e- other charged.
+c    general min = same as so far for e+/e-, p, heavy
+c                  mu, pi, K, --> dE/Ek< 1%; dE=Ek/100.
+c                  min=Ek/100/2e-3 g/cm2 = Ek/10/2e-3 kg/m2
+c                     =Ek/2e-2= 50Ek 
+c                  Ek=1  -->50 kg/m2  = 5g/cm2 ~5000cm ~50m
+c                  Ek=0.1-->5 kg/m2=0.5g/cm2   ~ 5m
+c                    0.01-->0.05kg/m2=0.05g/cm2 ~ 0.5m
+c                    0.001-->                     0.5m  
+c        
+c             ////////                   
+      do i = 1, NoOfSites
+         if( i .eq. 1) then
+            dstep = ObsSites(1).pos.depth 
+         else
+            dstep = ObsSites(i).pos.depth - ObsSites(i-1).pos.depth
+         endif
+         if(dstep  .lt. 15. )  then
+            StepControl=2
+         else
+            StepControl = dstep/25.0 
+         endif
+         maxstep(i) =   dstep/StepControl
       enddo
-      maxstep(1) =ObsSites(1).pos.depth /StepControl
 
-
-      RefreshIR = InitRN(1) .lt. 0 .and. 
-     *        ( Job .ne. 'flesh' .and. Job .ne. 'newflesh')
-
-      if(InitRN(1) .gt. 0 .and. InitRN(2) .gt. 0 ) then
-         call rnd1r(InitRN)     ! init randeom number generator
-c      *****************
-      elseif(.not. RefreshIR .and. InitRN(2) .lt. 0) then
-         call cmkSeed(0, now)   ! make seed using timer and hostname
-         call rnd1r(now)
-c           dummy use of 1000 times
-         do i = 1, 1000
-            call rndc(u)
-         enddo
-c     ******************
-      endif
 c          compute the offset point in 'xyz' system
 c        the deepest detector origin + Offset is the point
 c        to which the primary is directed.
@@ -252,6 +254,7 @@ c     ************
       subroutine  cwhatJob
 c     ************
       implicit none
+#include  "Zmanager.h"
 #include  "Zmanagerp.h"
 #include  "Ztrack.h"
 #include  "Ztrackv.h"
@@ -266,7 +269,27 @@ c
       integer klena, icon
       character*8  uid 
       character*16 temp
-      integer i
+      real*8 u
+      integer i, now(2)
+
+c      move from ciniTracking0  
+      RefreshIR = InitRN(1) .lt. 0 .and. 
+     *        ( Job .ne. 'flesh' .and. Job .ne. 'newflesh')
+
+      if(InitRN(1) .gt. 0 .and. InitRN(2) .gt. 0 ) then
+         call rnd1r(InitRN)     ! init randeom number generator
+c      *****************
+      elseif(.not. RefreshIR .and. InitRN(2) .lt. 0) then
+         call cmkSeed(0, now)   ! make seed using timer and hostname
+         call rnd1r(now)
+c           dummy use of 1000 times
+         do i = 1, 1000
+            call rndc(u)
+         enddo
+      endif
+c          this is almost ok but later once more saved.
+      call rnd1s(SeedSave)
+c     ******************
 
       if(KEminObs(2) .ne. KEminObs(1)) then
          write(0,*) ' KEminObs(2) is forced to be the same as'
@@ -336,6 +359,7 @@ c             skeleton file if distjob is employed.
                close(TempDev)
                Job = temp
             endif
+
 c                open SeedFile 
             if(SeedFile .eq. ' ') then
 c                error. you need file; not needed actually
