@@ -4,14 +4,6 @@
 #include  "Ztrackv.h"
       integer i
       character*70 msg
-
-c///////////////////
-c              to see possibility of photon projectile 
-c              with Primary is 'gamma' ;    see last
-c              part of this file.
-c      call cpredpmjet( MovedTrack.p,  Pwork, Nproduced)
-c//////////
-
       if(IntInfArray(ProcessNo).process .eq. 'pair') then
          call cpair
       elseif(IntInfArray(ProcessNo).process .eq. 'compt') then
@@ -212,40 +204,30 @@ c     ***********
       subroutine cphotop
 c     ***********
       implicit none
+c----      include '../Particle/Zcode.h'
 #include  "Zcode.h"
+c----      include 'Ztrack.h'
 #include  "Ztrack.h"
+c----      include 'Ztrackv.h'
 #include  "Ztrackv.h"
-#include  "Ztrackp.h"
 c
 c      record /track/aTrack
 c      integer i
 c
 c///////////////
-c      real*8 sum
-c      integer i
-c      record /ptcl/work(3000)
+      real*8 sum
+      integer i
+      record /ptcl/work(3000)
 c////////////
       integer ngen
-      Nproduced = 0
+
+      Nproduced = 0  ! in case of Cosmos, this has been done already 
 c//////////////
 c      write(0,*) ' in cphotop; bef cgpHad MoveE=',
 c     *     MovedTrack.p.fm.p(4)
 c//////////
-      if( HowPhotoP == 1 ) then
-         call csofia( TargetNucleonNo, TargetProtonNo, 
-     *      MovedTrack.p, Pwork(Nproduced+1), ngen)
-      elseif( HowPhotoP == 2 .or.
-     *  ( HowPhotoP == 3 .and. MovedTrack.p.fm.p(4) < 2.5 ) ) then
-         call cgpHad(TargetNucleonNo, TargetProtonNo, 
+      call cgpHad(TargetNucleonNo, TargetProtonNo, 
      *   MovedTrack.p, 2, Pwork(Nproduced+1), ngen)
-      elseif( HowPhotoP == 4 .and. MovedTrack.p.fm.p(4) > 2.5 ) then
-         call cgpHad(TargetNucleonNo, TargetProtonNo, 
-     *   MovedTrack.p, 2, Pwork(Nproduced+1), ngen)
-      else
-         ngen = 0
-      endif
-
-
 c
 c      call cgpHad(TargetNucleonNo, TargetProtonNo, 
 c     *   MovedTrack.p, 2, work, ngen)
@@ -402,19 +384,3 @@ c
       Nproduced = Nproduced + 1
       Pwork(Nproduced) = aTrack.p
       end
-      
-c/////////////
-      subroutine cpredpmjet(pj,  a, ntp)
-#include  "Zair.h"
-#include "Zptcl.h"
-      record /ptcl/  pj
-      integer ntp
-      record /ptcl/ a(*)
-      TargetNucleonNo=14
-      TargetProtonNo= 7 
-      call cdpmjet( pj, TargetNucleonNo, TargetProtonNo,
-     *   a, ntp)
-      write(0,*) ' ntp =',ntp
-      stop
-      end
-c/////////////
